@@ -1,7 +1,10 @@
 # -*- mode: cperl; tab-width: 8; indent-tabs-mode: nil; basic-offset: 2 -*-
 # vim:ts=8:sw=2:et:sta:sts=2
 #########
-# Author: rmp
+# Author:        rmp
+# Last Modified: $Date: 2013-12-26 22:25:17 +0000 (Thu, 26 Dec 2013) $
+# Id:            $Id: ADI.pm 344 2013-12-26 22:25:17Z rmp $
+# $HeadURL: svn+ssh://psyphi.net/repository/svn/iotamarathon/trunk/lib/Ham/ADIF/ADI.pm $
 #
 package Ham::ADIF::ADI;
 use strict;
@@ -12,7 +15,7 @@ use base qw(Ham::ADIF);
 use IO::File;
 use English qw(-no_match_vars);
 
-our $VERSION = q[1.5.2];
+our $VERSION = do { my ($r) = q$Revision: 344 $ =~ /(\d+)/smx; $r; };
 
 sub parse_file {
   my ($self, $filename) = @_;
@@ -28,7 +31,7 @@ sub parse_file {
   my $recs        = [];
 
   while(my $line = <$io>) {
-    if($line =~ m{<EOR>}smx) {
+    if($line =~ m{<EOR>}) {
       #########
       # JA1NLX - ADI with no header
       #
@@ -83,7 +86,7 @@ sub _process_header {
       next;
     }
 
-    my ($tagname, $length, $datatype, $value, $enum) = $tag =~ m{<(.*?):(\d+)(?::(.*?))?>(.*?)(?:,[{](.*?)[}])?$}smix;
+    my ($tagname, $length, $datatype, $value, $enum) = $tag =~ m{<(.*?):(\d+)(?::(.*?))?>(.*?)(?:,{(.*?)})?$}smix;
     if(!$tagname) {
       next;
     }
